@@ -1,5 +1,5 @@
 /*
-    Copyright ( C ) 2004 Arnold Krille <arnold@arnoldarts.de>
+    Copyright 2004 - 2007 Arnold Krille <arnold@arnoldarts.de>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -18,25 +18,36 @@
 
 */
 
-#include <iostream>
-#include <qapplication.h>
+#include <QtCore/QDebug>
+#include <QtCore/QFile>
+#include <QtGui/QApplication>
 
 #include "jack_backend.h"
 #include "mainwindow.h"
 
 int main( int argc, char** argv ) {
-	std::cout << "JackMix starting" << std::endl;
+	qDebug() << "JackMix starting";
 
 	QApplication *qapp = new QApplication( argc, argv );
+	QStringList args = qapp->arguments();
 
-	(void*) JackMix::JackBackend::backend();
+	QString file;
+	for( int i=1; i<args.size(); ++i ) {
+		qDebug() << QString( " arg %1: %2" ).arg( i ).arg( args[ i ] );
+		if ( QFile::exists( args[ i ] ) )
+			file = args[ i ];
+	}
 
-	JackMix::MainWindow *mw = new JackMix::MainWindow();
+	JackMix::MainWindow *mw;
+	if ( !file.isEmpty() )
+		mw = new JackMix::MainWindow( file );
+	else
+		mw = new JackMix::MainWindow();
 	mw->show();
 
-	qapp->setMainWidget( mw );
-
 	int ret = qapp->exec();
-	(void*) JackMix::JackBackend::backend( true );
+
+	delete mw;
+
 	return ret;
 }
